.. raw:: html

    <h1 align="center">Erin</h1>
    <p align="center">
        <a href="https://erin.rtfd.io"><img width="100" src="https://i.imgur.com/GK2KgOe.gif"/></a>
    </p>
    <p align="center">
        Batteries Included
        <br>
        <br>
        <a href="https://travis-ci.com/OpenDebates/Erin">
            <img src="https://travis-ci.com/OpenDebates/Erin.svg?branch=master"/>
        </a>
        <a href="https://ci.appveyor.com/project/daegontaven/erin">
            <img src="https://ci.appveyor.com/api/projects/status/dm6iw684c1lgji74?svg=true"/>
        </a>
        <a href="https://codeclimate.com/github/OpenDebates/Erin/maintainability">
            <img src="https://api.codeclimate.com/v1/badges/e5ea00ded93f855cb5a4/maintainability"/>
        </a>
        <a href="https://codecov.io/gh/OpenDebates/Erin">
            <img src="https://codecov.io/gh/OpenDebates/Erin/branch/master/graph/badge.svg"/>
        </a>
        <a href="https://erin.readthedocs.io/en/latest/?badge=latest">
            <img src="https://readthedocs.org/projects/erin/badge/?version=latest" alt='Documentation Status'/>
        </a>
    </p>
    <hr>
    <h4>What is Erin?</h4>
        <p>Erin is an initiative to build a bot development framework like how flask is a framework for web applications. It is built on top of the <a href="https://github.com/Rapptz/discord.py">discord.py</a> library and supports all of it's extensions by default.</p>

    <h4>Can I get started with Erin today?</h4>
       <p>Yes, Erin works out of the box with all <a href="https://github.com/Rapptz/discord.py">discord.py</a> <a href="https://discordpy.readthedocs.io/en/stable/ext/commands/api.html#discord.ext.commands.Bot.load_extension">extensions</a>. You can read how to set it up in the <a href="https://erin.readthedocs.io/en/latest/?badge=latest">documentation</a>. However, keep in mind that this project has not even released a pre-alpha yet. This is because we are still deliberating core architecture and we want to get it right the first time. As a result expect plenty of changes to the API without any notice at all.</p>
